import numpy as np

# sec = base unit
sec = 1
min = 60 * sec
h = 60 * min
ms = sec / 1000
us = ms / 1000
ns = us / 1000
ps = ns / 1000

# deg = base unit
deg = 1
rad = 180 / np.pi

# Hz is base unit
Hz = 1/sec
kHz = 1000 * Hz
MHz = 1000 * kHz
GHz = 1000 * MHz